时间轴 - Bootstrap后台管理系统模版Ace下载
Description: 站长素材提供Bootstrap模版,Bootstrap教程,Bootstrap中文翻译等相关Bootstrap插件下载
Keywords: Bootstrap模版,Bootstrap模版下载,Bootstrap教程,Bootstrap中文

# Timeline based on widget boxes with 2 different styles

Choose timeline:
1 2
Today
16:22

##### Susan reviewed a product

16:22
Anim pariatur cliche reprehenderit, enim eiusmod high life accusamus terry richardson ad squid …
Click to read …
Going to cafe for lunch
12:30

##### New logo

9:15
Designed a new logo for our website. Would appreciate feedback.
Took the final exam. Phew!
Yesterday

##### Haloween party

1 hour ago
Lots of fun at Haloween party.
Take a look at some pics:

##### Lorum Ipsum

Anim pariatur cliche reprehenderit, enim eiusmod high life accusamus terry richardson ad squid …
Going to cafe for lunch

##### Critical security patch released

9:15
Please download the new patch for maximum security.
May 17

##### Lorum Ipsum

10:22
Anim pariatur cliche reprehenderit, enim eiusmod high life accusamus terry richardson ad squid …
Today
11:15 pm
Susan reviewed a product
Click to read …
12:30 pm
Going to veg cafe for lunch
11:15 pm
Designed a new logo for our website. Would appreciate feedback. Click to see
9:00 am
Took the final exam. Phew!
Yesterday
9:00 am
Haloween party Lots of fun at Haloween party.
Take a look at some pics:
9:00 am
Anim pariatur cliche reprehenderit, enim eiusmod high life accusamus terry richardson ad squid …
9:00 am
Going to cafe for lunch
9:00 am
Critical security patch released
Please download the new patch for maximum security.
May 17
9:00 am
Lorum Ipsum Anim pariatur cliche reprehenderit, enim eiusmod high life accusamus terry richardson ad squid …
Choose Skin
Fixed Navbar
Fixed Sidebar
Fixed Breadcrumbs
Right To Left (rtl)
Inside .container